==> deepin-camera_6.0.11.tar.xz: BUILD/src/translations/deepin-camera_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Probíhá zaznamenávání videa. Zavřít okno?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotka</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Přepnout mezi kamerami</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Vytisknout</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nemáte oprávnění operovat v této složce</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Neplatná složka</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Základní</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Umístění souboru</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Snímek</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Dávkový režim</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Prodleva samospouště</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Výstupní formát</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ks</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ks</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je nástroj pro zachytávání obrazu a videa pomocí kamery počítače.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Soubor neuložen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Uložit do:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotka:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nastavení rozlišení</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Rozlišení:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotky:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videa:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Zvukové efekty</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Převrátit strany (jako v zrcadle)</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Přisvícení</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zastavit zaznamenávání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Vytisknout</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Přestat pořizovat fotky</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontextová nabídka</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Pořídit fotku</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Zaznamenat video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Přestat pořizovat fotky</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Přisvícení</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Prodleva zachycení</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenalezena žádná webová kamera</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webová kamera je používána</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Zastavit zaznamenávání</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Probíhá zaznamenávání videa. Zavřít okno?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotka</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Přepnout mezi kamerami</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Vytisknout</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Nemáte oprávnění operovat v této složce</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Neplatná složka</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otevřít složku</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Základní</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Umístění souboru</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Snímek</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Dávkový režim</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Prodleva samospouště</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Výstup</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Výstupní formát</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 ks</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 ks</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera je nástroj pro zachytávání obrazu a videa pomocí kamery počítače.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Soubor neuložen</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Uložit do:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotka:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Nastavení rozlišení</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Rozlišení:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotky:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videa:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Zvukové efekty</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Převrátit strany (jako v zrcadle)</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>Přisvícení</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation>Čáry mřížky</translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation>1 ⨉ 1 čára</translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation>2 ⨉ 2 čáry</translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Zastavit zaznamenávání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Zkopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Vytisknout</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Přestat pořizovat fotky</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Kontextová nabídka</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Pořídit fotku</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Zaznamenat video</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Přestat pořizovat fotky</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Živé</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Teplé</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Studené</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Šedé</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>ČB</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>Přisvícení</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Zapnuto</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Prodleva zachycení</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Žádné</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtry</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Expozice</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Nenalezena žádná webová kamera</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Webová kamera je používána</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Zastavit zaznamenávání</translation>
    </message>
</context>
</TS>
